@@ -28,6 +28,7 @@ from source.dataset.commands import dataset as dataset_group
 from source.org.commands import org as org_group
 from source.access.commands import access as access_group
 from source.graph.commands import graph as graph_group
+from source.hierarchy.commands import hierarchy as hierarchy_group
 
 from source._version import __version__
 
@@ -60,6 +61,7 @@ cli.add_command(dataset_group)
 cli.add_command(org_group)
 cli.add_command(access_group)
 cli.add_command(graph_group)
+cli.add_command(hierarchy_group)
 
 if __name__ == '__main__':
     cli()
