@@ -13,7 +13,9 @@
 # limitations under the License.
 
 from click.testing import CliRunner
-from source.ah import org_add, add_cluster, login
+from source.org.commands import org_add
+from source.cluster.commands import add_cluster
+from source.cluster.commands import login
 from tests.properties import Properties
 import uuid
 import re
